# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model-init.j2

"""Auto-generated package that contains models used by the AccelByte Gaming Services Login Queue Service."""

__version__ = "2.2.1"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .apimodels_configuration_request import ApimodelsConfigurationRequest
from .apimodels_configuration_response import ApimodelsConfigurationResponse
from .apimodels_link import ApimodelsLink
from .apimodels_queue_status_response import ApimodelsQueueStatusResponse
from .apimodels_refresh_ticket_response import ApimodelsRefreshTicketResponse
from .response_error import ResponseError
